roveapi

package
v0.34.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 19, 2020 License: MIT Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	CommandType_name = map[int32]string{
		0: "none",
		1: "move",
		2: "stash",
		3: "repair",
		4: "recharge",
		5: "broadcast",
	}
	CommandType_value = map[string]int32{
		"none":      0,
		"move":      1,
		"stash":     2,
		"repair":    3,
		"recharge":  4,
		"broadcast": 5,
	}
)

Enum value maps for CommandType.

var (
	Bearing_name = map[int32]string{
		0: "BearingUnknown",
		1: "North",
		2: "East",
		3: "South",
		4: "West",
	}
	Bearing_value = map[string]int32{
		"BearingUnknown": 0,
		"North":          1,
		"East":           2,
		"South":          3,
		"West":           4,
	}
)

Enum value maps for Bearing.

var (
	Object_name = map[int32]string{
		0: "ObjectUnknown",
		1: "RoverLive",
		2: "RockSmall",
		3: "RockLarge",
	}
	Object_value = map[string]int32{
		"ObjectUnknown": 0,
		"RoverLive":     1,
		"RockSmall":     2,
		"RockLarge":     3,
	}
)

Enum value maps for Object.

var (
	Tile_name = map[int32]string{
		0: "TileUnknown",
		1: "Rock",
		2: "Gravel",
		3: "Sand",
	}
	Tile_value = map[string]int32{
		"TileUnknown": 0,
		"Rock":        1,
		"Gravel":      2,
		"Sand":        3,
	}
)

Enum value maps for Tile.

var File_roveapi_roveapi_proto protoreflect.FileDescriptor

Functions

func RegisterRoveServer

func RegisterRoveServer(s *grpc.Server, srv RoveServer)

Types

type Account

type Account struct {

	// The account name
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// The account secret value, given when creating the account
	Secret string `protobuf:"bytes,2,opt,name=secret,proto3" json:"secret,omitempty"`
	// contains filtered or unexported fields
}

Account describes a registered account

func (*Account) Descriptor deprecated

func (*Account) Descriptor() ([]byte, []int)

Deprecated: Use Account.ProtoReflect.Descriptor instead.

func (*Account) GetName

func (x *Account) GetName() string

func (*Account) GetSecret

func (x *Account) GetSecret() string

func (*Account) ProtoMessage

func (*Account) ProtoMessage()

func (*Account) ProtoReflect

func (x *Account) ProtoReflect() protoreflect.Message

func (*Account) Reset

func (x *Account) Reset()

func (*Account) String

func (x *Account) String() string

type Bearing added in v0.34.0

type Bearing int32
const (
	// BearingUnknown an unknown invalid bearing
	Bearing_BearingUnknown Bearing = 0
	Bearing_North          Bearing = 1
	Bearing_East           Bearing = 2
	Bearing_South          Bearing = 3
	Bearing_West           Bearing = 4
)

func (Bearing) Descriptor added in v0.34.0

func (Bearing) Descriptor() protoreflect.EnumDescriptor

func (Bearing) Enum added in v0.34.0

func (x Bearing) Enum() *Bearing

func (Bearing) EnumDescriptor deprecated added in v0.34.0

func (Bearing) EnumDescriptor() ([]byte, []int)

Deprecated: Use Bearing.Descriptor instead.

func (Bearing) Number added in v0.34.0

func (x Bearing) Number() protoreflect.EnumNumber

func (Bearing) String added in v0.34.0

func (x Bearing) String() string

func (Bearing) Type added in v0.34.0

func (Bearing) Type() protoreflect.EnumType

type Command

type Command struct {

	// The command type
	Command CommandType `protobuf:"varint,1,opt,name=command,proto3,enum=roveapi.CommandType" json:"command,omitempty"`
	// Types that are assignable to Data:
	//	*Command_Bearing
	//	*Command_Message
	Data isCommand_Data `protobuf_oneof:"data"`
	// contains filtered or unexported fields
}

Command is a single command for a rover

func (*Command) Descriptor deprecated

func (*Command) Descriptor() ([]byte, []int)

Deprecated: Use Command.ProtoReflect.Descriptor instead.

func (*Command) GetBearing

func (x *Command) GetBearing() Bearing

func (*Command) GetCommand

func (x *Command) GetCommand() CommandType

func (*Command) GetData

func (m *Command) GetData() isCommand_Data

func (*Command) GetMessage

func (x *Command) GetMessage() []byte

func (*Command) ProtoMessage

func (*Command) ProtoMessage()

func (*Command) ProtoReflect

func (x *Command) ProtoReflect() protoreflect.Message

func (*Command) Reset

func (x *Command) Reset()

func (*Command) String

func (x *Command) String() string

type CommandRequest

type CommandRequest struct {

	// The account to execute these commands
	Account *Account `protobuf:"bytes,1,opt,name=account,proto3" json:"account,omitempty"`
	// The set of desired commands
	Commands []*Command `protobuf:"bytes,2,rep,name=commands,proto3" json:"commands,omitempty"`
	// contains filtered or unexported fields
}

CommandRequest describes a set of commands to be requested for the rover

func (*CommandRequest) Descriptor deprecated

func (*CommandRequest) Descriptor() ([]byte, []int)

Deprecated: Use CommandRequest.ProtoReflect.Descriptor instead.

func (*CommandRequest) GetAccount

func (x *CommandRequest) GetAccount() *Account

func (*CommandRequest) GetCommands

func (x *CommandRequest) GetCommands() []*Command

func (*CommandRequest) ProtoMessage

func (*CommandRequest) ProtoMessage()

func (*CommandRequest) ProtoReflect

func (x *CommandRequest) ProtoReflect() protoreflect.Message

func (*CommandRequest) Reset

func (x *CommandRequest) Reset()

func (*CommandRequest) String

func (x *CommandRequest) String() string

type CommandResponse

type CommandResponse struct {
	// contains filtered or unexported fields
}

CommandResponse is an empty placeholder

func (*CommandResponse) Descriptor deprecated

func (*CommandResponse) Descriptor() ([]byte, []int)

Deprecated: Use CommandResponse.ProtoReflect.Descriptor instead.

func (*CommandResponse) ProtoMessage

func (*CommandResponse) ProtoMessage()

func (*CommandResponse) ProtoReflect

func (x *CommandResponse) ProtoReflect() protoreflect.Message

func (*CommandResponse) Reset

func (x *CommandResponse) Reset()

func (*CommandResponse) String

func (x *CommandResponse) String() string

type CommandType

type CommandType int32

CommandType defines the type of a command to give to the rover

const (
	CommandType_none CommandType = 0
	// Move the rover in a direction, requires bearing
	CommandType_move CommandType = 1
	// Stashes item at current location in rover inventory
	CommandType_stash CommandType = 2
	// Repairs the rover using an inventory object
	CommandType_repair CommandType = 3
	// Waits a tick to add more charge to the rover
	CommandType_recharge CommandType = 4
	// Broadcasts a message to nearby rovers
	CommandType_broadcast CommandType = 5
)

func (CommandType) Descriptor

func (CommandType) Enum

func (x CommandType) Enum() *CommandType

func (CommandType) EnumDescriptor deprecated

func (CommandType) EnumDescriptor() ([]byte, []int)

Deprecated: Use CommandType.Descriptor instead.

func (CommandType) Number

func (x CommandType) Number() protoreflect.EnumNumber

func (CommandType) String

func (x CommandType) String() string

func (CommandType) Type

type Command_Bearing

type Command_Bearing struct {
	// A bearing
	// Used with MOVE
	Bearing Bearing `protobuf:"varint,2,opt,name=bearing,proto3,enum=roveapi.Bearing,oneof"`
}

type Command_Message

type Command_Message struct {
	// A simple message, must be composed of printable ASCII glyphs (32-126)
	// maximum of three characters
	// Used with BROADCAST
	Message []byte `protobuf:"bytes,3,opt,name=message,proto3,oneof"`
}

type Log

type Log struct {

	// The unix timestamp of the log
	Time string `protobuf:"bytes,1,opt,name=time,proto3" json:"time,omitempty"`
	// The text of the log
	Text string `protobuf:"bytes,2,opt,name=text,proto3" json:"text,omitempty"`
	// contains filtered or unexported fields
}

Log is a single log item

func (*Log) Descriptor deprecated

func (*Log) Descriptor() ([]byte, []int)

Deprecated: Use Log.ProtoReflect.Descriptor instead.

func (*Log) GetText

func (x *Log) GetText() string

func (*Log) GetTime

func (x *Log) GetTime() string

func (*Log) ProtoMessage

func (*Log) ProtoMessage()

func (*Log) ProtoReflect

func (x *Log) ProtoReflect() protoreflect.Message

func (*Log) Reset

func (x *Log) Reset()

func (*Log) String

func (x *Log) String() string

type Object added in v0.33.0

type Object int32

Types of objects

const (
	// ObjectUnknown represents no object at all
	Object_ObjectUnknown Object = 0
	// RoverLive represents a live rover
	Object_RoverLive Object = 1
	// RockSmall is a small stashable rock
	Object_RockSmall Object = 2
	// RockLarge is a large blocking rock
	Object_RockLarge Object = 3
)

func (Object) Descriptor added in v0.33.0

func (Object) Descriptor() protoreflect.EnumDescriptor

func (Object) Enum added in v0.33.0

func (x Object) Enum() *Object

func (Object) EnumDescriptor deprecated added in v0.33.0

func (Object) EnumDescriptor() ([]byte, []int)

Deprecated: Use Object.Descriptor instead.

func (Object) Number added in v0.33.0

func (x Object) Number() protoreflect.EnumNumber

func (Object) String added in v0.33.0

func (x Object) String() string

func (Object) Type added in v0.33.0

func (Object) Type() protoreflect.EnumType

type RadarRequest

type RadarRequest struct {

	// The account for this request
	Account *Account `protobuf:"bytes,1,opt,name=account,proto3" json:"account,omitempty"`
	// contains filtered or unexported fields
}

RadarRequest is the data needed to request the radar for a rover

func (*RadarRequest) Descriptor deprecated

func (*RadarRequest) Descriptor() ([]byte, []int)

Deprecated: Use RadarRequest.ProtoReflect.Descriptor instead.

func (*RadarRequest) GetAccount

func (x *RadarRequest) GetAccount() *Account

func (*RadarRequest) ProtoMessage

func (*RadarRequest) ProtoMessage()

func (*RadarRequest) ProtoReflect

func (x *RadarRequest) ProtoReflect() protoreflect.Message

func (*RadarRequest) Reset

func (x *RadarRequest) Reset()

func (*RadarRequest) String

func (x *RadarRequest) String() string

type RadarResponse

type RadarResponse struct {

	// The range in tiles from the rover of the radar data
	Range int32 `protobuf:"varint,1,opt,name=range,proto3" json:"range,omitempty"`
	// A 1D array representing range*2 + 1 squared set of tiles, origin bottom
	// left and in row->column order
	Tiles []Tile `protobuf:"varint,2,rep,packed,name=tiles,proto3,enum=roveapi.Tile" json:"tiles,omitempty"`
	// A similar array to the tile array, but containing objects
	Objects []Object `protobuf:"varint,3,rep,packed,name=objects,proto3,enum=roveapi.Object" json:"objects,omitempty"`
	// contains filtered or unexported fields
}

RadarResponse describes radar information

func (*RadarResponse) Descriptor deprecated

func (*RadarResponse) Descriptor() ([]byte, []int)

Deprecated: Use RadarResponse.ProtoReflect.Descriptor instead.

func (*RadarResponse) GetObjects

func (x *RadarResponse) GetObjects() []Object

func (*RadarResponse) GetRange

func (x *RadarResponse) GetRange() int32

func (*RadarResponse) GetTiles

func (x *RadarResponse) GetTiles() []Tile

func (*RadarResponse) ProtoMessage

func (*RadarResponse) ProtoMessage()

func (*RadarResponse) ProtoReflect

func (x *RadarResponse) ProtoReflect() protoreflect.Message

func (*RadarResponse) Reset

func (x *RadarResponse) Reset()

func (*RadarResponse) String

func (x *RadarResponse) String() string

type RegisterRequest

type RegisterRequest struct {

	// The desired account name
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// contains filtered or unexported fields
}

RegisterRequest contains data to register an account

func (*RegisterRequest) Descriptor deprecated

func (*RegisterRequest) Descriptor() ([]byte, []int)

Deprecated: Use RegisterRequest.ProtoReflect.Descriptor instead.

func (*RegisterRequest) GetName

func (x *RegisterRequest) GetName() string

func (*RegisterRequest) ProtoMessage

func (*RegisterRequest) ProtoMessage()

func (*RegisterRequest) ProtoReflect

func (x *RegisterRequest) ProtoReflect() protoreflect.Message

func (*RegisterRequest) Reset

func (x *RegisterRequest) Reset()

func (*RegisterRequest) String

func (x *RegisterRequest) String() string

type RegisterResponse

type RegisterResponse struct {

	// The registered account information
	Account *Account `protobuf:"bytes,1,opt,name=account,proto3" json:"account,omitempty"`
	// contains filtered or unexported fields
}

RegisterResponse is the response given to registering an account

func (*RegisterResponse) Descriptor deprecated

func (*RegisterResponse) Descriptor() ([]byte, []int)

Deprecated: Use RegisterResponse.ProtoReflect.Descriptor instead.

func (*RegisterResponse) GetAccount

func (x *RegisterResponse) GetAccount() *Account

func (*RegisterResponse) ProtoMessage

func (*RegisterResponse) ProtoMessage()

func (*RegisterResponse) ProtoReflect

func (x *RegisterResponse) ProtoReflect() protoreflect.Message

func (*RegisterResponse) Reset

func (x *RegisterResponse) Reset()

func (*RegisterResponse) String

func (x *RegisterResponse) String() string

type RoveClient

type RoveClient interface {
	// Server status
	// Responds with various details about the current server status
	ServerStatus(ctx context.Context, in *ServerStatusRequest, opts ...grpc.CallOption) (*ServerStatusResponse, error)
	// Register an account
	// Tries to register an account with the given name
	Register(ctx context.Context, in *RegisterRequest, opts ...grpc.CallOption) (*RegisterResponse, error)
	// Send commands to rover
	// Sending commands to this endpoint will queue them to be executed during the
	// following ticks, in the order sent. Commands sent within the same tick will
	// overwrite until the tick has finished and the commands are queued
	Command(ctx context.Context, in *CommandRequest, opts ...grpc.CallOption) (*CommandResponse, error)
	// Get radar information
	// Gets the radar output for the given rover
	Radar(ctx context.Context, in *RadarRequest, opts ...grpc.CallOption) (*RadarResponse, error)
	// Get rover information
	// Gets information for the account's rover
	Status(ctx context.Context, in *StatusRequest, opts ...grpc.CallOption) (*StatusResponse, error)
}

RoveClient is the client API for Rove service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.

func NewRoveClient

func NewRoveClient(cc grpc.ClientConnInterface) RoveClient

type RoveServer

type RoveServer interface {
	// Server status
	// Responds with various details about the current server status
	ServerStatus(context.Context, *ServerStatusRequest) (*ServerStatusResponse, error)
	// Register an account
	// Tries to register an account with the given name
	Register(context.Context, *RegisterRequest) (*RegisterResponse, error)
	// Send commands to rover
	// Sending commands to this endpoint will queue them to be executed during the
	// following ticks, in the order sent. Commands sent within the same tick will
	// overwrite until the tick has finished and the commands are queued
	Command(context.Context, *CommandRequest) (*CommandResponse, error)
	// Get radar information
	// Gets the radar output for the given rover
	Radar(context.Context, *RadarRequest) (*RadarResponse, error)
	// Get rover information
	// Gets information for the account's rover
	Status(context.Context, *StatusRequest) (*StatusResponse, error)
}

RoveServer is the server API for Rove service.

type ServerStatusRequest

type ServerStatusRequest struct {
	// contains filtered or unexported fields
}

ServerStatusRequest is an empty placeholder

func (*ServerStatusRequest) Descriptor deprecated

func (*ServerStatusRequest) Descriptor() ([]byte, []int)

Deprecated: Use ServerStatusRequest.ProtoReflect.Descriptor instead.

func (*ServerStatusRequest) ProtoMessage

func (*ServerStatusRequest) ProtoMessage()

func (*ServerStatusRequest) ProtoReflect

func (x *ServerStatusRequest) ProtoReflect() protoreflect.Message

func (*ServerStatusRequest) Reset

func (x *ServerStatusRequest) Reset()

func (*ServerStatusRequest) String

func (x *ServerStatusRequest) String() string

type ServerStatusResponse

type ServerStatusResponse struct {

	// The version of the server in v{major}.{minor}-{delta}-{sha} form
	Version string `protobuf:"bytes,1,opt,name=version,proto3" json:"version,omitempty"`
	// Whether the server is ready to accept requests
	Ready bool `protobuf:"varint,2,opt,name=ready,proto3" json:"ready,omitempty"`
	// The tick rate of the server in minutes (how many minutes per tick)
	TickRate int32 `protobuf:"varint,3,opt,name=tickRate,proto3" json:"tickRate,omitempty"`
	// The current tick of the server
	CurrentTick int32 `protobuf:"varint,4,opt,name=currentTick,proto3" json:"currentTick,omitempty"`
	// The time the next tick will occur
	NextTick string `protobuf:"bytes,5,opt,name=next_tick,json=nextTick,proto3" json:"next_tick,omitempty"`
	// contains filtered or unexported fields
}

ServerStatusResponse is a response with useful server information

func (*ServerStatusResponse) Descriptor deprecated

func (*ServerStatusResponse) Descriptor() ([]byte, []int)

Deprecated: Use ServerStatusResponse.ProtoReflect.Descriptor instead.

func (*ServerStatusResponse) GetCurrentTick

func (x *ServerStatusResponse) GetCurrentTick() int32

func (*ServerStatusResponse) GetNextTick

func (x *ServerStatusResponse) GetNextTick() string

func (*ServerStatusResponse) GetReady

func (x *ServerStatusResponse) GetReady() bool

func (*ServerStatusResponse) GetTickRate

func (x *ServerStatusResponse) GetTickRate() int32

func (*ServerStatusResponse) GetVersion

func (x *ServerStatusResponse) GetVersion() string

func (*ServerStatusResponse) ProtoMessage

func (*ServerStatusResponse) ProtoMessage()

func (*ServerStatusResponse) ProtoReflect

func (x *ServerStatusResponse) ProtoReflect() protoreflect.Message

func (*ServerStatusResponse) Reset

func (x *ServerStatusResponse) Reset()

func (*ServerStatusResponse) String

func (x *ServerStatusResponse) String() string

type StatusRequest

type StatusRequest struct {

	// The account for this request
	Account *Account `protobuf:"bytes,1,opt,name=account,proto3" json:"account,omitempty"`
	// contains filtered or unexported fields
}

StatusRequest is information needed to request rover status

func (*StatusRequest) Descriptor deprecated

func (*StatusRequest) Descriptor() ([]byte, []int)

Deprecated: Use StatusRequest.ProtoReflect.Descriptor instead.

func (*StatusRequest) GetAccount

func (x *StatusRequest) GetAccount() *Account

func (*StatusRequest) ProtoMessage

func (*StatusRequest) ProtoMessage()

func (*StatusRequest) ProtoReflect

func (x *StatusRequest) ProtoReflect() protoreflect.Message

func (*StatusRequest) Reset

func (x *StatusRequest) Reset()

func (*StatusRequest) String

func (x *StatusRequest) String() string

type StatusResponse

type StatusResponse struct {

	// The name of the rover
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Position of the rover in world coordinates
	Position *Vector `protobuf:"bytes,2,opt,name=position,proto3" json:"position,omitempty"`
	// The range of this rover's radar and broadcasting
	Range int32 `protobuf:"varint,3,opt,name=range,proto3" json:"range,omitempty"`
	// The items in the rover inventory
	Inventory []byte `protobuf:"bytes,4,opt,name=inventory,proto3" json:"inventory,omitempty"`
	// The capacity of the inventory
	Capacity int32 `protobuf:"varint,5,opt,name=capacity,proto3" json:"capacity,omitempty"`
	// The current health of the rover
	Integrity int32 `protobuf:"varint,6,opt,name=integrity,proto3" json:"integrity,omitempty"`
	// The maximum health of the rover
	MaximumIntegrity int32 `protobuf:"varint,7,opt,name=maximumIntegrity,proto3" json:"maximumIntegrity,omitempty"`
	// The energy stored in the rover
	Charge int32 `protobuf:"varint,8,opt,name=charge,proto3" json:"charge,omitempty"`
	// The max energy the rover can store
	MaximumCharge int32 `protobuf:"varint,9,opt,name=maximumCharge,proto3" json:"maximumCharge,omitempty"`
	// The set of currently incoming commands for this tick
	IncomingCommands []*Command `protobuf:"bytes,10,rep,name=incomingCommands,proto3" json:"incomingCommands,omitempty"`
	// The set of currently queued commands
	QueuedCommands []*Command `protobuf:"bytes,11,rep,name=queuedCommands,proto3" json:"queuedCommands,omitempty"`
	// The most recent logs
	Logs []*Log `protobuf:"bytes,12,rep,name=logs,proto3" json:"logs,omitempty"`
	// contains filtered or unexported fields
}

StatusResponse is the response given to a status request

func (*StatusResponse) Descriptor deprecated

func (*StatusResponse) Descriptor() ([]byte, []int)

Deprecated: Use StatusResponse.ProtoReflect.Descriptor instead.

func (*StatusResponse) GetCapacity

func (x *StatusResponse) GetCapacity() int32

func (*StatusResponse) GetCharge

func (x *StatusResponse) GetCharge() int32

func (*StatusResponse) GetIncomingCommands

func (x *StatusResponse) GetIncomingCommands() []*Command

func (*StatusResponse) GetIntegrity

func (x *StatusResponse) GetIntegrity() int32

func (*StatusResponse) GetInventory

func (x *StatusResponse) GetInventory() []byte

func (*StatusResponse) GetLogs

func (x *StatusResponse) GetLogs() []*Log

func (*StatusResponse) GetMaximumCharge

func (x *StatusResponse) GetMaximumCharge() int32

func (*StatusResponse) GetMaximumIntegrity

func (x *StatusResponse) GetMaximumIntegrity() int32

func (*StatusResponse) GetName

func (x *StatusResponse) GetName() string

func (*StatusResponse) GetPosition

func (x *StatusResponse) GetPosition() *Vector

func (*StatusResponse) GetQueuedCommands

func (x *StatusResponse) GetQueuedCommands() []*Command

func (*StatusResponse) GetRange

func (x *StatusResponse) GetRange() int32

func (*StatusResponse) ProtoMessage

func (*StatusResponse) ProtoMessage()

func (*StatusResponse) ProtoReflect

func (x *StatusResponse) ProtoReflect() protoreflect.Message

func (*StatusResponse) Reset

func (x *StatusResponse) Reset()

func (*StatusResponse) String

func (x *StatusResponse) String() string

type Tile added in v0.33.0

type Tile int32
const (
	// TileUnknown is a keyword for nothing
	Tile_TileUnknown Tile = 0
	// Rock is solid rock ground
	Tile_Rock Tile = 1
	// Gravel is loose rocks
	Tile_Gravel Tile = 2
	// Sand is sand
	Tile_Sand Tile = 3
)

func (Tile) Descriptor added in v0.33.0

func (Tile) Descriptor() protoreflect.EnumDescriptor

func (Tile) Enum added in v0.33.0

func (x Tile) Enum() *Tile

func (Tile) EnumDescriptor deprecated added in v0.33.0

func (Tile) EnumDescriptor() ([]byte, []int)

Deprecated: Use Tile.Descriptor instead.

func (Tile) Number added in v0.33.0

func (x Tile) Number() protoreflect.EnumNumber

func (Tile) String added in v0.33.0

func (x Tile) String() string

func (Tile) Type added in v0.33.0

func (Tile) Type() protoreflect.EnumType

type UnimplementedRoveServer

type UnimplementedRoveServer struct {
}

UnimplementedRoveServer can be embedded to have forward compatible implementations.

func (*UnimplementedRoveServer) Command

func (*UnimplementedRoveServer) Radar

func (*UnimplementedRoveServer) Register

func (*UnimplementedRoveServer) ServerStatus

func (*UnimplementedRoveServer) Status

type Vector

type Vector struct {
	X int32 `protobuf:"varint,1,opt,name=x,proto3" json:"x,omitempty"`
	Y int32 `protobuf:"varint,2,opt,name=y,proto3" json:"y,omitempty"`
	// contains filtered or unexported fields
}

Vector describes a point or vector in 2D space

func (*Vector) Descriptor deprecated

func (*Vector) Descriptor() ([]byte, []int)

Deprecated: Use Vector.ProtoReflect.Descriptor instead.

func (*Vector) GetX

func (x *Vector) GetX() int32

func (*Vector) GetY

func (x *Vector) GetY() int32

func (*Vector) ProtoMessage

func (*Vector) ProtoMessage()

func (*Vector) ProtoReflect

func (x *Vector) ProtoReflect() protoreflect.Message

func (*Vector) Reset

func (x *Vector) Reset()

func (*Vector) String

func (x *Vector) String() string

Jump to